==> apache-cxf-3.4.7-src.tar.gz: apache-cxf-3.4.7-src/systests/jaxws/src/test/java/org/apache/cxf/systest/jaxws/Echo.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.jaxws;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "echo", propOrder = { "string1" })
public class Echo {

    @XmlElement(name = "String_1",
                namespace = "http://cxf.apache.org/systest/jaxws/DocLitWrappedCodeFirstService",
                required = true,
                nillable = true)
    protected String string1;

    /**
     * Gets the value of the string1 property.
     *
     * @return
     *     possible object is
     *     {@link String }
     *
     */
    public String getString1() {
        return string1;
    }

    /**
     * Sets the value of the string1 property.
     *
     * @param value
     *     allowed object is
     *     {@link String }
     *
     */
    public void setString1(String value) {
        this.string1 = value;
    }

}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/systests/jaxws/src/test/java/org/apache/cxf/systest/jaxws/Echo.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.jaxws;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "echo", propOrder = { "string1" })
public class Echo {

    @XmlElement(name = "String_1",
                namespace = "http://cxf.apache.org/systest/jaxws/DocLitWrappedCodeFirstService",
                required = true,
                nillable = true)
    protected String string1;

    /**
     * Gets the value of the string1 property.
     *
     * @return
     *     possible object is
     *     {@link String }
     *
     */
    public String getString1() {
        return string1;
    }

    /**
     * Sets the value of the string1 property.
     *
     * @param value
     *     allowed object is
     *     {@link String }
     *
     */
    public void setString1(String value) {
        this.string1 = value;
    }

}
